json_schema_utils library

JSONSchema Utils

A library for working with JSON Schema documents.

Classes

ArraySchema
Represents a JSON Schema for an array type.
JsonSchema
A base class representing a JSON Schema.
NumberSchema
Represents a JSON Schema for a number or integer type.
ObjectSchema
Represents a JSON Schema for an object type.
StringSchema
Represents a JSON Schema for a string type.

Enums

JsonType
An enum representing the primitive types allowed in JSON Schema.
StringFormat
An enum for the standard string formats defined in JSON Schema.