json_schema_utils library
JSONSchema Utils
A library for working with JSON Schema documents.
Classes
- ArraySchema
-
Represents a JSON Schema for an
arraytype. - JsonSchema
- A base class representing a JSON Schema.
- NumberSchema
-
Represents a JSON Schema for a
numberorintegertype. - ObjectSchema
-
Represents a JSON Schema for an
objecttype. - StringSchema
-
Represents a JSON Schema for a
stringtype.
Enums
- JsonType
- An enum representing the primitive types allowed in JSON Schema.
- StringFormat
- An enum for the standard string formats defined in JSON Schema.